@@ -1,4 +1,3 @@
-__version__ = '0.1.1'
-
+from pytorch_partial_crf.marginal_crf import MarginalCRF
 from pytorch_partial_crf.partial_crf import PartialCRF
 from pytorch_partial_crf.crf import CRF
